@@ -328,10 +328,11 @@ class requestManager:
 
     def make_request(self):
         """
-        Make a request and handle potential errors.
+        Make a request and handle potential errors, with retries.
         """
         if self.url_mgr.url is None:
             return None
+
         self.wait_between_requests()
         for _ in range(self.max_retries):
             try:
@@ -345,41 +346,52 @@ class requestManager:
                         elif self._response.status_code == 429:
                             logging.warning(f"Rate limited by {self.url_mgr.url}. Retrying...")
                             time.sleep(5)
+                    else:
+                        # String/bytes from Selenium path
+                        self.status_code = 200
+                        return self._response
             except requests.Timeout as e:
                 logging.error(f"Request to {self.url_mgr.url} timed out: {e}")
             except requests.ConnectionError:
                 logging.error(f"Connection error for URL {self.url_mgr.url}.")
             except requests.RequestException as e:
                 logging.error(f"Request exception for URL {self.url_mgr.url}: {e}")
-        try:
-            response = get_selenium_source(self.url_mgr.url)
-            if response:
-                self._response = response
-                self.status_code = 200  # Assume success
-                return self._response
-        except Exception as e:
-            logging.error(f"Failed to retrieve content from {self.url_mgr.url} after {self.max_retries} retries: {e}")
-            return None
+
+        logging.error(f"Failed to retrieve content from {self.url_mgr.url} after {self.max_retries} retries")
+        return None
 
     def try_request(self) -> requests.Response | str | bytes | None:
         """
-        Tries to make an HTTP request to the given URL using the provided session.
+        Tries Selenium first, then falls back to requests if Selenium fails.
         """
         if self.url_mgr.url is None:
             return None
+
+        # 1. Try Selenium
         try:
-            return get_selenium_source(self.url_mgr.url)  # or self.session.get(self.url_mgr.url, timeout=self.timeout, stream=self.stream)
+            return get_selenium_source(self.url_mgr.url)
+        except Exception as e:
+            logging.warning(f"Selenium failed for {self.url_mgr.url}, falling back to requests: {e}")
+
+        # 2. Fallback: requests
+        try:
+            resp = self.session.get(
+                self.url_mgr.url,
+                timeout=self.timeout or 10,
+                stream=self.stream
+            )
+            return resp
         except requests.RequestException as e:
-            logging.error(f"Request failed: {e}")
+            logging.error(f"Requests fallback also failed for {self.url_mgr.url}: {e}")
             return None
 
-    @property
-    def url(self):
-        return self.url_mgr.url
+        @property
+        def url(self):
+            return self.url_mgr.url
 
-    @url.setter
-    def url(self, new_url):
-        self._url = new_url
+        @url.setter
+        def url(self, new_url):
+            self._url = new_url
 class SafeRequestSingleton:
     _instance = None
     @staticmethod
